// @flow

import fs from 'fs';
import ora from 'ora';
import isString from 'lodash/isString';

import { resolvePath } from '../utils';
import logger from '../logger';
import {
  component,
} from '../template';

export default function generate(type: string, name: string) {
  if (!isString(type)) {
    throw new TypeError('type is not a string');
  }

  if (!isString(name)) {
    throw new TypeError('name is not a string');
  }

  const destination = resolvePath(name);

  fs.writeFile(destination, component, (error) => {
    if (error) {
      throw error;
    }

    const spinner = ora(`Generating ${type} in ${name}...`).start();

    if (error) {
      logger.error(error);
      spinner.fail();
      return;
    }

    spinner.succeed();
  });
}
